@@ -115,6 +115,16 @@ DOCUMENTATION__install = SwaggerDocumentation(
     )
 )
 
+DOCUMENTATION__is_installed = SwaggerDocumentation(
+    tags="Installation",
+    security=False,
+    methods=SwaggerMethod(
+        name="Is installed",
+        description="Returns 200 OK if the service has installed otherwise a 422",
+        method=REST__GET
+    )
+)
+
 # Not unused. Used to generate html files
 from jaaql.documentation.documentation_shared import DOCUMENTATION__oauth_token, DOCUMENTATION__oauth_refresh
 
@@ -337,6 +347,7 @@ DOCUMENTATION__applications = SwaggerDocumentation(
                     condition="Only updated if supplied",
                     description="New application name",
                     arg_type=str,
+                    required=False,
                     example=["Library Browser", "Meeting Room Scheduling Assistant"]
                 ),
                 SwaggerArgumentResponse(
@@ -344,6 +355,7 @@ DOCUMENTATION__applications = SwaggerDocumentation(
                     condition="Only updated if supplied",
                     description="New application description",
                     arg_type=str,
+                    required=False,
                     example=["Browses books in the library", "Helps book meetings"]
                 ),
                 SwaggerArgumentResponse(
@@ -351,6 +363,7 @@ DOCUMENTATION__applications = SwaggerDocumentation(
                     condition="Only updated if supplied",
                     description="New application url",
                     arg_type=str,
+                    required=False,
                     example=["https://jaaql.com/demos/library-application",
                              "https://jaaql.com/demos/meeting-application"]
                 )
@@ -757,7 +770,7 @@ DOCUMENTATION__activate = SwaggerDocumentation(
 )
 
 DOCUMENTATION__users_confirm_revoke = SwaggerDocumentation(
-    tags="Users",
+    tags="User Management",
     methods=SwaggerMethod(
         name="Confirm user revoke",
         description="Confirm the revoke of a user, providing a single use deletion key",
