@@ -25,7 +25,6 @@ from jaaql.constants import *
 from os.path import join
 from jaaql.utilities.utils import get_jaaql_root
 import threading
-import shutil
 
 TOKEN__pre_auth_reduction_factor = 15
 
@@ -40,6 +39,7 @@ ERR__duplicated_database = "User %s has a duplicate database precedence with dat
 ERR__not_sole_owner = "You are not the sole owner of this connection"
 ERR__mfa_must_be_enabled = "MFA must be turned on!"
 ERR__cannot_self_sign_up = "Cannot self sign up. Must be invited to the platform"
+ERR__not_installed = "The platform is not installed yet"
 
 USERNAME__jaaql = "jaaql"
 USERNAME__superjaaql = "superjaaql"
@@ -372,6 +372,10 @@ class JAAQLModel(BaseJAAQLModel):
         return crypt_utils.jwt_encode(self.vault.get_obj(VAULT_KEY__jwt_crypt_key), jwt_data,
                                       expiry_ms=expiry_time)
 
+    def is_installed(self):
+        if self.jaaql_lookup_connection is None:
+            raise HttpStatusException(ERR__not_installed)
+
     def install(self, db_connection_string: str, superjaaql_password: str, password: str, install_key: str,
                 use_mfa: bool, ip_address: str, user_agent: str, response: JAAQLResponse):
         if not use_mfa and self.force_mfa:
@@ -438,7 +442,7 @@ class JAAQLModel(BaseJAAQLModel):
                 super_used_id = self.create_user(self.jaaql_lookup_connection, USERNAME__superjaaql,
                                                  superjaaql_db_password, attach_as=USERNAME__postgres,
                                                  precedence=PRECEDENCE__super_user)
-                super_mfa = self.sign_up_user(self.jaaql_lookup_connection, USERNAME__superjaaql, password,
+                super_mfa = self.sign_up_user(self.jaaql_lookup_connection, USERNAME__superjaaql, superjaaql_password,
                                               super_used_id, ip_address, user_agent, use_mfa=use_mfa)
                 super_otp_uri = super_mfa[KEY__otp_uri]
                 super_otp_qr = super_mfa[KEY__otp_qr]
